unit param_config;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, INIFiles;
const
  TCP_SOCKET_PORT = 2000;
  IniFilename = 'mote.ini';

var

  Hostname             : String = 'localhost';
  TEMP_ALARM_SECS      : Word   = $001F;
  TEMP_ALARM_THRESHOLD : Word   = $0190;
  BATT_ALARM_SECS      : Word   = $001F;
  BATT_ALARM_THRESHOLD : Word   = $0190;
  DEBUG_SECS           : Word   = $0050;
  CHANNEL              : Byte   = 26;
  ChannelHasChanged    : Boolean;

procedure ReadIniFile;
procedure WriteIniFile;
function  parseAlarm(inputstr: string): String;
function  parsePing(inputstr: string): String;
function  parseIAMNODE(inputstr: string): String;
procedure getLineValues( InputLine: string; var date, alrm_kind, is_alarm, node,
                         alarm_kindnr, value, serial, rssi: string);
function  alarmstr2grid(InputLine: string): string;
function  parseConf(inputstr: string): String;
procedure ConfLine2UpdateConf(InputLine: string);
function  alarmstr2select(InputLine: string): string;


implementation
var
  IFile: TIniFile;

function StringtoHex(Data: string): string;
var
  i, i2: Integer;
  s: string='';
begin
  i2 := 1;
  for i := 1 to Length(Data) do
  begin
    Inc(i2);
    if i2 = 2 then
    begin
      s  := s + ' ';
      i2 := 1;
    end;
    s := s + IntToHex(Ord(Data[i]), 2);
  end;
  Result := s;
end;

function HexStrToDec(Str: string): Integer;
var
  i, M: Integer;
begin
  Result:=0;
  M:=1;
  Str:=AnsiUpperCase(Str);
  for i:=Length(Str) downto 1 do
  begin
    case Str[i] of
      '1'..'9': Result:=Result+(Ord(Str[i])-Ord('0'))*M;
      'A'..'F': Result:=Result+(Ord(Str[i])-Ord('A')+10)*M;
    end;
    M:=M shl 4;
  end;
end;

procedure ReadIniFile();
begin
     // IniFile Section

     IFile := TIniFile.Create(IniFilename);

     if IFile.ValueExists('CONFIG','hostname') then
        hostname:=IFile.ReadString('CONFIG','hostname',hostname);

     if IFile.ValueExists('CONFIG','TEMP_ALARM_SECS') then
        TEMP_ALARM_SECS:=IFile.ReadInteger('CONFIG',
          'TEMP_ALARM_SECS',TEMP_ALARM_SECS);

     if IFile.ValueExists('CONFIG','TEMP_ALARM_THRESHOLD') then
        TEMP_ALARM_THRESHOLD:=IFile.ReadInteger('CONFIG',
          'TEMP_ALARM_THRESHOLD',TEMP_ALARM_THRESHOLD);

     if IFile.ValueExists('CONFIG','BATT_ALARM_SECS') then
        BATT_ALARM_SECS:=IFile.ReadInteger('CONFIG',
          'BATT_ALARM_SECS',BATT_ALARM_SECS);

     if IFile.ValueExists('CONFIG','BATT_ALARM_THRESHOLD') then
        BATT_ALARM_THRESHOLD:=IFile.ReadInteger('CONFIG',
          'BATT_ALARM_THRESHOLD',BATT_ALARM_THRESHOLD);

     if IFile.ValueExists('CONFIG','DEBUG_SECS') then
        DEBUG_SECS:=IFile.ReadInteger('CONFIG',
          'DEBUG_SECS',DEBUG_SECS);

     if IFile.ValueExists('CONFIG','CHANNEL') then
        CHANNEL:=IFile.ReadInteger('CONFIG',
          'CHANNEL',CHANNEL);

     IFile.Free;
end;

procedure WriteIniFile();
begin
    IFile := TIniFile.Create(IniFilename);
    IFile.WriteString ('CONFIG','hostname',hostname);
    IFile.WriteInteger('CONFIG','TEMP_ALARM_SECS',TEMP_ALARM_SECS);
    IFile.WriteInteger('CONFIG','TEMP_ALARM_THRESHOLD',TEMP_ALARM_THRESHOLD);
    IFile.WriteInteger('CONFIG','BATT_ALARM_SECS',BATT_ALARM_SECS);
    IFile.WriteInteger('CONFIG','BATT_ALARM_THRESHOLD',TEMP_ALARM_THRESHOLD);
    IFile.WriteInteger('CONFIG','DEBUG_SECS',DEBUG_SECS);
    IFile.WriteInteger('CONFIG','CHANNEL',CHANNEL);
    IFile.UpdateFile;
    IFile.Free;

end;
function parseAlarm(inputstr: string): String;
var
   tempstr: string;
begin
  tempstr:=StringReplace(inputstr,'     ',',',[rfReplaceAll]);
  tempstr:=StringReplace(tempstr,' ','',[rfReplaceAll]);
  tempstr:=StringReplace(tempstr,'+','',[rfReplaceAll]);
  tempstr:=FormatDateTime('YYYYMMDD_hh:nn:ss,',Now)+tempstr;
  Insert(',',tempstr,34);
  Insert(',',tempstr,30);
  Insert(',',tempstr,28);
  Insert(',',tempstr,24);
  parsealarm:=tempstr;
end;

function parsePing(inputstr: string): String;
var
   tempstr: string;
begin
  tempstr:=StringReplace(inputstr,'   ',',',[rfReplaceAll]);
  tempstr:=StringReplace(tempstr,' ','',[rfReplaceAll]);
  tempstr:=StringReplace(tempstr,'+','',[rfReplaceAll]);
  tempstr:=FormatDateTime('YYYYMMDD_hh:nn:ss,',Now)+tempstr;
  Insert(',',tempstr,36);
  Insert(',',tempstr,32);
  Insert(',',tempstr,30);
  Insert(',',tempstr,26);
  parseping:=tempstr;
end;

function parseIAMNODE(inputstr: string): String;
var
   SplitLine: TStringList;

   tempstr, rootnode: string;
begin
  tempstr:=StringReplace(inputstr,' ',',',[rfReplaceAll]);
  SplitLine :=TStringList.Create;
  SplitLine.clear;
  SplitLine.StrictDelimiter:=True;
  SplitLine.delimiter:=',';
  SplitLine.delimitedText:=tempstr;
  rootnode     :=     SplitLine[1];
  SplitLine.Free;
  parseIAMNODE:=rootnode;
end;


procedure getLineValues( InputLine: string; var date, alrm_kind, is_alarm, node,
                         alarm_kindnr, value, serial, rssi: string);
var
   SplitLine: TStringList;
begin
     SplitLine :=TStringList.Create;
     SplitLine.clear;
     SplitLine.StrictDelimiter:=True;
     SplitLine.delimiter:=',';
     SplitLine.delimitedText:=InputLine;
     date         :=     SplitLine[0];
     alrm_kind    :=     SplitLine[1];
     is_alarm     :=     SplitLine[2];
     node         :=     SplitLine[3];
     alarm_kindnr :=     SplitLine[4];
     value        :=     SplitLine[5];
     serial       :=     SplitLine[6];
     rssi         :=     SplitLine[7];
     SplitLine.Free;
end;

function alarmstr2grid(InputLine: string): string;
var
   SplitLine: TStringList;
   TempStr: string;
   date, alrm_kind, is_alarm, node,
   alarm_kindnr, value, serial, rssi: string;
begin
     SplitLine :=TStringList.Create;
     SplitLine.clear;
     SplitLine.StrictDelimiter:=True;
     SplitLine.delimiter:=',';
     SplitLine.delimitedText:=InputLine;
     date         :=     SplitLine[0];
     alrm_kind    :=     SplitLine[1];
     is_alarm     :=     SplitLine[2];
     node         :=     SplitLine[3];
     alarm_kindnr :=     SplitLine[4];
     value        :=     SplitLine[5];
     serial       :=     SplitLine[6];
     rssi         :=     SplitLine[7];
     SplitLine.Free;
     alarmstr2grid:=alrm_kind+','+node+','+value+','+date+','+ serial+','+rssi;
end;

function alarmstr2select(InputLine: string): string;
var
   SplitLine: TStringList;
   TempStr: string;
   date, alrm_kind, is_alarm, node,
   alarm_kindnr, value, serial, rssi: string;
begin
     SplitLine :=TStringList.Create;
     SplitLine.clear;
     SplitLine.StrictDelimiter:=True;
     SplitLine.delimiter:=',';
     SplitLine.delimitedText:=InputLine;
     alrm_kind         :=     SplitLine[0];
     node              :=     SplitLine[1];
     value             :=     SplitLine[2];
     date              :=     SplitLine[3];
     serial            :=     SplitLine[4];
     SplitLine.Free;
     alarmstr2select:=alrm_kind+'|'+ serial+'|'+node+'|'+date;
end;

function parseConf(inputstr: string): String;
var
   tempstr: string;
begin
  tempstr:=StringReplace(inputstr,'+','',[rfReplaceAll]);
  tempstr:=StringReplace(tempstr,' ',',',[rfReplaceAll]);
  Insert(',',tempstr,29);
  Insert(',',tempstr,25);
  Insert(',',tempstr,21);
  Insert(',',tempstr,17);
  Insert(',',tempstr,13);
  parseConf:=tempstr;
end;

procedure ConfLine2UpdateConf(InputLine: string);
var
   SplitLine: TStringList;
   TempStr: string;
   g_cmd, g_nodeid : string;
begin
     SplitLine :=TStringList.Create;
     SplitLine.clear;
     SplitLine.StrictDelimiter:=True;
     SplitLine.delimiter:=',';
     SplitLine.delimitedText:=InputLine;
     g_cmd                   :=                 SplitLine[0];
     CHANNEL                 :=     HexStrToDec(SplitLine[1]);
     g_nodeid                :=                 SplitLine[2];
     TEMP_ALARM_SECS         :=     HexStrToDec(SplitLine[3]);
     TEMP_ALARM_THRESHOLD    :=     HexStrToDec(SplitLine[4]);
     BATT_ALARM_SECS         :=     HexStrToDec(SplitLine[5]);
     BATT_ALARM_THRESHOLD    :=     HexStrToDec(SplitLine[6]);
//     TempStr      :=     alarm_kind+','+node+','+value+','+date+','+
//                         serial+','+rssi;
     SplitLine.Free;

end;

end.

