/* vi: set number syntax=c ruler smartindent autoindent tabstop=8 shiftwidth=8 : */
#ifndef BEACON_DEF_H
#define BEACON_DEF_H

//#undef HAD_SIREN_HARDWARE
#define HAD_SIREN_HARDWARE
// Si se conecta el siguiente hard. al conector, definir 'HAD_SIREN_HARDWARE'
//
// Correspondencia hard:
// atm1281   ATZB-24A2  CON Signal         470 Ohm PullUp Resistor
//  N/A       N/A       14  3V3         o----/\/\/----+-----+
//                                                    |     |  _ o Piezzo
//                                                   _i_    _ / |  Buzzer
//                                                <- \ /     {  |  3V
//                                                <-  V     _ \ |
//                                                   ---    |  -
//                                                    |     |
// port G2    pin 21    15  GPIO5_CON   <=------------+-----+
//
// 

typedef enum {
	BEACON_LED_STATUS_CLEAR	= 0,
	BEACON_LED_STATUS_FIXED,
	BEACON_LED_STATUS_HALF,
	BEACON_LED_STATUS_1_FLASH,
	BEACON_LED_STATUS_2_FLASH,
	BEACON_LED_STATUS_OTHER
} beacon_led_state_t;

typedef enum {
	BEACON_BOOTED		= 0,	// Flash de 500 ms los tres leds
	BEACON_NETWORK_SCAN,		// todo
	BEACON_NETWORK_DETECTED,	// 1F LV
	BEACON_NETWORK_NOT_FOUND,	// 2F LV
	BEACON_BATTERY_LOW,		// 2F LN
	BEACON_TEMP_DEBUG,		// 1F LN
	BEACON_ALARM_DISABLED,		// 1F LR
	BEACON_ALARM_DETECTED,		// 2F LR + fijo LN
	BEACON_ALARM_SENT,		// 1S LR
	BEACON_ALARM_ACKED,		// 1S LR
	BEACON_ALARM_CLEARED,		// reboot -> todo en BeaconCtrlP + watchdog
	BEACON_ALARM_ACTIVE,		// fijo LR
	BEACON_SPECIAL,			// todo
	BEACON_CLEAR_R,			// clear LR
	BEACON_CLEAR_N,			// clear LN
	BEACON_CLEAR_V			// clear LV
} beacon_state;

typedef enum {
	LED_TIMMING_CYCLE_0C	=  500,		// do not count, first state
	LED_TIMMING_CYCLE_1C	=   50,		// acum =     5ms
	LED_TIMMING_CYCLE_2C	=  450,		// acum =   500ms
	LED_TIMMING_CYCLE_3C	=   50,		// acum =   505ms
	LED_TIMMING_CYCLE_4C	=  450,		// acum =  1000ms
	LED_TIMMING_CYCLE_5C	= 1000,		// acum =  2000ms
	LED_TIMMING_CYCLE_6C	= 2000	   	// acum =  4000ms
} led_timmings;

typedef enum {
	LED_CYCLE_0C		= 0,
	LED_CYCLE_1C		= 1,
	LED_CYCLE_2C		= 2,
	LED_CYCLE_3C		= 3,
	LED_CYCLE_4C		= 4,
	LED_CYCLE_5C		= 5,
	LED_CYCLE_6C		= 6
} led_cycle_state;

typedef enum {
	LED_PATTERN_CLEAR	= 1,	// off
	LED_PATTERN_1_FLASH	= 2,	// (x1) 5ms flash
	LED_PATTERN_2_FLASH	= 3,	// (x2) 5ms flash
	LED_PATTERN_500MS_ON	= 4,	// 500ms on + 3500ms off
	LED_PATTERN_1S_ON	= 5,	// 1000ms on + 3000ms off 
	LED_PATTERN_HALF	= 6,	// 2000ms on + 2000ms off
	LED_PATTERN_FIXED	= 7	// 4000ms on
} led_timming_state;

typedef enum {
	LED_OFF			= 0,
	LED_ON			= 1
} led_states;

#endif


